# -*- coding: utf-8 -*-
import os
from uuid import uuid4

from django.db import models
from django.urls import reverse
from ckeditor_uploader.fields import RichTextUploadingField
from easy_thumbnails.fields import ThumbnailerImageField


class Page(models.Model):
    class Meta:
        verbose_name = "페이지"
        verbose_name_plural = "페이지 목록"

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        return "/%s/" % self.code

    code = models.SlugField('페이지 코드', unique=True)
    title = models.CharField('페이지 제목', max_length=40)
    subtitle = models.CharField('페이지 부제목(선택)', max_length=100, blank=True, null=True)
    featured = ThumbnailerImageField('타이틀 이미지', upload_to='featured',
                                     blank=True, null=True, help_text='이미지 추가 시 페이지 상단에 이미지 타이틀이 표시 됩니다.')

    content = RichTextUploadingField('페이지 내용', config_name='page')
    style = models.TextField('Style', default='', blank=True, null=True)
    script = models.TextField('Script', default='', blank=True, null=True)

    updated = models.DateTimeField('업데이트', auto_now=True)
    created = models.DateTimeField('생성일', auto_now_add=True)


def path_and_rename(instance, filename):
    prefix = "slide"
    ext = filename.split('.')[-1]
    page = "pid_%s" % (instance.page.id,)
    # get filename
    if instance.pk:
        complaint_id = "cid_%s" % (instance.pk,)
        filename = '{}.{}.{}.{}'.format(prefix, page, complaint_id, ext)
    else:
        # set filename as random string
        random_id = "rid_%s" % (uuid4().hex,)
        filename = '{}.{}.{}.{}'.format(prefix, page, random_id, ext)

        # return the whole path to the file
    return os.path.join("slide", filename)


class Slide(models.Model):
    class Meta:
        verbose_name = "슬라이드"
        verbose_name_plural = "슬라이드"
        ordering = ['order']

    def __str__(self):
        return self.title

    def get_delay_as_msec(self):
        return self.delay * 1000

    page = models.ForeignKey(Page, on_delete=models.CASCADE, related_name='slides')
    order = models.PositiveIntegerField('슬라이드 순서', default=0, db_index=True)

    image = ThumbnailerImageField(help_text='슬라이드 이미지', upload_to=path_and_rename)

    title = models.CharField('제목', max_length=40, blank=True, default="")
    subtitle = models.CharField('부제목', max_length=100, blank=True, default="")
    description = models.TextField('추가설명', null=True, blank=True)

    delay = models.PositiveIntegerField('표시시간', default=12, help_text='슬라이드가 표시되는 시간(초)')

    button_label = models.CharField('버튼 이름 제목', max_length=40, blank=True, null=True, help_text='공백인 경우 버튼이 표시 되지 않음')
    button_link = models.URLField('버튼 링크', blank=True, null=True)


class Pagelet(models.Model):
    class Meta:
        verbose_name = "반복사용문구"
        verbose_name_plural = "반복사용문구 목록"

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        return "/%s/" % self.code

    title = models.CharField('문구 제목', max_length=40)
    code = models.SlugField('문구 코드', unique=True)

    content = RichTextUploadingField('문구 내용', config_name='pagelet', null=True, blank=True, default="")

    updated = models.DateTimeField('업데이트', auto_now=True)
    created = models.DateTimeField('생성일', auto_now_add=True)


class PostCategory(models.Model):
    class Meta:
        verbose_name = "포스트 카테고리"
        verbose_name_plural = "포스트 카테고리 목록"

    def __str__(self):
        return self.name

    code = models.CharField('카테고리 코드', max_length=10, primary_key=True)
    name = models.CharField('카테고리 제목', max_length=40)
    desc = models.CharField('카테고리 한줄 설명', max_length=80)
    link = models.CharField('키테고리 페이지 링크', max_length=1024, null=True, blank=True)

    template = models.CharField('특수 템플릿',
                                max_length=80,
                                default=None,
                                null=True,
                                blank=True,
                                help_text="이 카테고리가 특수한 템플릿을 쓸 경우 템플릿명"
                                )


class Post(models.Model):
    class Meta:
        verbose_name = "포스트"
        verbose_name_plural = "포스트 목록"

        ordering = ['-topmost', '-created']

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        if self.cate.code == 'faq':
            return "/prepare/#faq-%s" % self.pk

        return reverse("page:post", args=[self.id])

    cate = models.ForeignKey(PostCategory, blank=True, null=True, on_delete=models.CASCADE)

    topmost = models.BooleanField("상단고정", default=False, help_text='선택 시 리스트 상단에 고정 됩니다.')
    active = models.BooleanField('표시여부', default=True, help_text='체크 되어 있을 때 리스트에 표시 됩니다')
    featured = ThumbnailerImageField('타이틀 이미지', upload_to='featured',
                                     blank=True, null=True, help_text='이미지 추가 시 페이지 상단에 이미지 타이틀이 표시 됩니다.')

    title = models.CharField('포스트 제목', max_length=40)
    content = RichTextUploadingField('포스트 내용', config_name='post')
    summary = models.TextField('요약 내용')

    updated = models.DateTimeField('업데이트', auto_now=True)
    created = models.DateTimeField('생성일', auto_now_add=True)


class DownloadableFile(models.Model):

    class Meta:
        verbose_name = "다운로드용 파일"
        verbose_name_plural = "다운로드용 파일 목록"

    def __str__(self):
        return self.name or "-"

    name = models.CharField('표시 할 파일명', max_length=40)
    file = models.FileField('양식 파일', upload_to="forms", null=True, blank=True)

    created = models.DateField('생성일자', auto_now_add=True)


class Popup(models.Model):

    class Meta:
        verbose_name = "팝업창"
        verbose_name_plural = "팝업창 목록"

    def __str__(self):
        return self.title

    title = models.CharField('제목', max_length=300, help_text='관리자 구분용이고 외부에 표출되지 않습니다.')
    page = models.ForeignKey(Page, verbose_name='표출 할 페이지', on_delete=models.CASCADE)

    is_active = models.BooleanField('활성화 여부', default=False)

    pos_x = models.CharField('팝업 가로 위치', max_length=100, default='50px')
    pos_y = models.CharField('팝업 세로 위치', max_length=100, default='150px')

    content = RichTextUploadingField('팝업 내용', config_name='post', help_text='팝업 내용을 직접 작성하는 경우 입력', blank=True, null=True)
    image = models.ImageField('풀 이미지 팝업', upload_to='popup', blank=True, null=True, help_text='설정시 전체 팝업 내용은 이미지로만 채워집니다.')

    created = models.DateTimeField('생성일', auto_now_add=True)



import re
from pprint import pprint

from django.conf import settings
from django.template import RequestContext, Template

REMAP_COMMANDS = {
    "페이지넣기": "page",
    "반복문구넣기": "pagelet",
    "포함하기": "include",
    "가져오기": "include",
    "다운로드": "download",
}

if hasattr(settings, "PAGE_SHORTCODES"):
    REMAP_COMMANDS = { **REMAP_COMMANDS, **settings.PAGE_SHORTCODES}

UNPACK_WITH = [
    'page',
]

if hasattr(settings, "PAGE_UNPACK_WITH"):
    UNPACK_WITH = (*UNPACK_WITH, *settings.PAGE_UNPACK_WITH)


def remap_and_markup(matches):
    groups = tuple(map(lambda x: x.strip(), matches.groups()))

    command = groups[0]
    args = groups[1].split()

    if command in REMAP_COMMANDS.keys():
        command = REMAP_COMMANDS[command]
    elif command in REMAP_COMMANDS.values():
        pass
    else:
        return "[등록되지 않은 단축어 사용]"

    if command == "include":
        args[0] = settings.PAGE_TARGET_MAP.get(args[0], args[0])

    args = map(lambda x: '"%s"' % x, args)

    template_code = '{%% %s %s %%}' % (command, " ".join(args))
    return template_code


def unpack_shortcode(content):
    key_and_command = list(REMAP_COMMANDS.keys()) + list(REMAP_COMMANDS.values())
    full_commands = "|".join(key_and_command)
    return re.sub(r'\[(' + full_commands + ')(.+?)\]', remap_and_markup, content, flags=re.IGNORECASE)


def unpack_content_with_request(request, content, data=None):
    if data is None:
        data = {}
    return unpack_content(content, RequestContext(request, data))


def unpack_content(content, context):
    content = "".join(["{%% load %s %%}" % tags for tags in UNPACK_WITH]) + unpack_shortcode(content)
    return Template(content).render(context)



# Generated by Django 2.1.7 on 2019-03-14 14:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0011_popup'),
    ]

    operations = [
        migrations.AlterField(
            model_name='popup',
            name='image',
            field=models.ImageField(blank=True, help_text='설정시 전체 팝업 내용은 이미지로만 채워집니다.', null=True, upload_to='popup', verbose_name='풀 이미지 팝업'),
        ),
        migrations.AlterField(
            model_name='popup',
            name='pos_y',
            field=models.CharField(default='150px', max_length=100, verbose_name='팝업 세로 위치'),
        ),
        migrations.AlterField(
            model_name='popup',
            name='title',
            field=models.CharField(help_text='관리자 구분용이고 외부에 표출되지 않습니다.', max_length=300, verbose_name='제목'),
        ),
    ]



# Generated by Django 2.0.5 on 2018-12-08 11:18

from django.db import migrations, models
import django.db.models.deletion
import easy_thumbnails.fields


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0005_auto_20181202_1846'),
    ]

    operations = [
        migrations.CreateModel(
            name='Slide',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(db_index=True, default=0, verbose_name='슬라이드 순서')),
                ('image', easy_thumbnails.fields.ThumbnailerImageField(help_text='슬라이드 이미지', upload_to='slide')),
                ('title', models.CharField(max_length=40, verbose_name='제목')),
                ('subtitle', models.CharField(max_length=100, verbose_name='부제목')),
                ('description', models.TextField(blank=True, null=True, verbose_name='추가설명')),
                ('delay', models.PositiveIntegerField(default=12, verbose_name='표시시간')),
                ('button_label', models.CharField(blank=True, max_length=40, null=True, verbose_name='버튼 이름 제목')),
                ('button_link', models.URLField(blank=True, null=True, verbose_name='버튼 링크')),
            ],
            options={
                'verbose_name': '슬라이드',
                'verbose_name_plural': '슬라이드 목록',
                'ordering': ['order'],
            },
        ),
        migrations.RemoveField(
            model_name='page',
            name='theme',
        ),
        migrations.AlterField(
            model_name='page',
            name='featured',
            field=easy_thumbnails.fields.ThumbnailerImageField(blank=True, help_text='이미지 추가 시 페이지 상단에 이미지 타이틀이 표시 됩니다.', null=True, upload_to='featured', verbose_name='타이틀 이미지'),
        ),
        migrations.AddField(
            model_name='slide',
            name='page',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='slides', to='page.Page'),
        ),
    ]



from adminsortable2.admin import SortableInlineAdminMixin
from django.contrib import admin
from django.core.cache import cache
from reversion.admin import VersionAdmin

from page.models import Page, Pagelet, DownloadableFile, Post, PostCategory, Slide, Popup


class SlideInline(SortableInlineAdminMixin, admin.StackedInline):
    sortable = "order"
    model = Slide
    extra = 0

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


class PopupInline(admin.StackedInline):
    model = Popup
    extra = 0


@admin.register(Page)
class PageAdmin(VersionAdmin):
    list_display = ['title', 'code', 'id', 'updated', 'created']
    inlines = [SlideInline, PopupInline]

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


@admin.register(Pagelet)
class PageletAdmin(VersionAdmin):
    list_display = ['title', 'code', 'id', 'updated', 'created']

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


@admin.register(DownloadableFile)
class DownloadableFileAdmin(VersionAdmin):
    list_display = ['name', 'file', ]

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


@admin.register(Post)
class PostAdmin(VersionAdmin):
    list_display = ['title', 'active', 'topmost', 'created', 'cate']
    list_editable = ['active', 'topmost']
    list_filter = ['cate', 'active', 'topmost']

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


@admin.register(PostCategory)
class PostCategoryAdmin(admin.ModelAdmin):

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()





# -*- coding: utf-8 -*-
from django import template
from django.urls import reverse
from django.utils.safestring import mark_safe

import os

from page.models import Page, Pagelet, DownloadableFile
from page.shortcode import unpack_content_with_request

register = template.Library()


@register.simple_tag(takes_context=True)
def page(context, page_code):
    if not page_code:
        return ""

    page_obj, _ = Page.objects.get_or_create(code=page_code, defaults={'title': page_code, 'content': page_code})
    return unpack_content_with_request(context['request'], page_obj.content, {
        'title': page_obj.title,
        'edit': reverse('admin:page_page_change', args=[page_obj.id])
    })


@register.simple_tag(takes_context=True)
def pagelet(context, pagelet_code):
    if not pagelet_code:
        return ""

    try:
        pagelet_obj = Pagelet.objects.get(title=pagelet_code)
    except Pagelet.DoesNotExist:
        pagelet_obj, _ = Pagelet.objects.get_or_create(code=pagelet_code,
                                                       defaults={'title': pagelet_code, 'content': pagelet_code})

    return unpack_content_with_request(context['request'], pagelet_obj.content, {
        'title': pagelet_obj.title,
        'edit': reverse('admin:page_page_change', args=[pagelet_obj.id])
    })


@register.simple_tag(takes_context=True)
def pagelet_title(context, pagelet_code):
    if not pagelet_code:
        return ""

    try:
        pagelet_obj = Pagelet.objects.get(title=pagelet_code)
    except Pagelet.DoesNotExist:
        pagelet_obj, _ = Pagelet.objects.get_or_create(code=pagelet_code,
                                                       defaults={'title': pagelet_code, 'content': pagelet_code})

    return pagelet_obj.title


@register.simple_tag
def download(value, color='button-border white'):
    try:
        int_value = int(value)
        target = DownloadableFile.objects.get(pk=int_value)
    except (ValueError, DownloadableFile.DoesNotExist):
        target = None

    if not target:
        try:
            target = DownloadableFile.objects.get(name=value)
        except DownloadableFile.DoesNotExist:
            return ""

    if not target.file:
        return mark_safe("""<a class="button %s" href="#" 
            data-toggle="modal" data-target="#error-dialog" data-message="죄송합니다! %s 다운로드가 아직 준비되지 않았습니다."> 
            <span> %s 다운받기</span>
            <i class="fa fa-download"></i>
            </a>""" % (color, target.name, target.name))

    url = reverse("page:download", args=(target.pk,)) + os.path.basename(target.file.name)

    return mark_safe("""<a class="button %s" href="%s">
                        <span>%s 다운받기</span>
                        <i class="fa fa-download"></i>
                    </a>""" % (color ,url, target.name))


@register.simple_tag
def view(value):
    try:
        int_value = int(value)
        target = DownloadableFile.objects.get(pk=int_value)
    except (ValueError, DownloadableFile.DoesNotExist):
        target = None

    if not target:
        try:
            target = DownloadableFile.objects.get(name=value)
        except DownloadableFile.DoesNotExist:
            return ""

    return mark_safe(
        '<a class="btn btn-primary" href="%s"><i class="fa fa-eye"></i> "%s" 보기</a>' % (target.file.url, target.name))



# Generated by Django 2.1.4 on 2018-12-09 12:17

from django.db import migrations, models
import easy_thumbnails.fields
import page.models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0007_auto_20181208_2123'),
    ]

    operations = [
        migrations.AlterField(
            model_name='slide',
            name='image',
            field=easy_thumbnails.fields.ThumbnailerImageField(help_text='슬라이드 이미지', upload_to=page.models.path_and_rename),
        ),
        migrations.AlterField(
            model_name='slide',
            name='subtitle',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='부제목'),
        ),
        migrations.AlterField(
            model_name='slide',
            name='title',
            field=models.CharField(blank=True, default='', max_length=40, verbose_name='제목'),
        ),
    ]



# -*- coding: utf-8 -*-

from django.urls import path, re_path

from . import views

app_name = "page"

urlpatterns = [
    re_path(r'^download/(?P<file_id>\d+)/', views.download, name='download'),

    path('post/<int:post_id>/', views.post, name='post'),
    path('post/<str:cate_id>/', views.post_list, name='post_list'),

    path('<int:page_id>/', views.page, name='page_by_id'),
    path('<slug:page_code>/', views.page, name='page_by_code'),

    path('', views.page, {'page_code': 'home'}, name='home'),
]



# Generated by Django 2.1.5 on 2019-01-20 16:57

import ckeditor_uploader.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0009_post_featured'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagelet',
            name='content',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, default='', null=True, verbose_name='문구 내용'),
        ),
    ]



# Generated by Django 2.0.5 on 2018-11-13 19:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='post',
            old_name='summery',
            new_name='summary',
        ),
    ]



# -*- coding: utf-8 -*-
import urllib

import re
import os
from django import template
from django.conf import settings

from django.shortcuts import render, get_object_or_404
from django.template import Template, RequestContext, Context
from django.http import Http404, HttpResponse
from django.urls import reverse

from page.models import Page, DownloadableFile, Post, PostCategory

from django.core.exceptions import ObjectDoesNotExist

from page.shortcode import unpack_content_with_request


def page(request, page_id=None, page_code=None):

    if not page_id and not page_code:
        raise Http404("Page does not exist")

    page_obj = None

    try:
        if page_id:
            page_obj = Page.objects.get(pk=page_id)

        if page_code:
            page_obj = Page.objects.get(code=page_code)

    except ObjectDoesNotExist:
        raise Http404("Page does not exist")

    if not page_obj:
        raise Http404("Page does not exist")

    content = unpack_content_with_request(request, page_obj.content, {
        'title': page_obj.title,
        'edit': reverse('admin:page_page_change', args=[page_obj.id])
    })

    return render(request, 'page/page/page.html', {
        'page': page_obj,
        'content': content,
        'edit': reverse('admin:page_page_change', args=[page_obj.id]),
        'default_featured': settings.PAGE_FEATURED_DEFAULT if hasattr(settings, "PAGE_FEATURED_DEFAULT") else ''
        })


def post(request, post_id):
    if not post_id:
        raise Http404("Page does not exist")

    try:
        post_obj = Post.objects.get(pk=post_id)
    except Post.DoesNotExist:
        post_obj = Post.objects.all().order_by('-created')[0]

    content = unpack_content_with_request(request, post_obj.content)

    return render(request, 'page/post/post.html', {
        'title': post_obj.title,
        'post': post_obj,
        'content': content,
        'cate': post_obj.cate,
        'edit': reverse('admin:page_post_change', args=[post_obj.id]),
        'default_featured': settings.PAGE_FEATURED_DEFAULT if hasattr(settings, "PAGE_FEATURED_DEFAULT") else ''
    })


def post_list(request, cate_id):
    cate = get_object_or_404(PostCategory, code=cate_id)
    posts = Post.objects.filter(active=True, cate=cate)

    default_selected = 0
    if posts:
        default_selected = posts[0].id

    try:
        selected = int(request.GET.get('id', default_selected))
    except ValueError:
        selected = default_selected

    return render(request, 'page/post/list.html', {
        'style_name': 'page/post/style/' + (cate.template or 'basic_list.html'),
        'cate': cate,
        'posts': posts,
        'selected': selected,
    })


def download(request, file_id):
    file_obj = get_object_or_404(DownloadableFile, pk=file_id)

    file_name = os.path.basename(file_obj.file.name)

    response = HttpResponse(file_obj.file, content_type='application/octet-stream')

    filename_header = 'filename*=UTF-8\'\'%s' % urllib.parse.quote(file_name.encode('utf-8'))
    response['Content-Disposition'] = 'attachment; ' + filename_header

    return response



# -*- coding: utf-8 -*-
from django import template
from page.models import Post, PostCategory
from django.shortcuts import render, get_object_or_404
from django.template.loader import render_to_string

register = template.Library()


@register.simple_tag
def get_posts(category_code, limit=4):
    return Post.objects.filter(active=True, cate__code=category_code)[:limit]


@register.simple_tag
def get_category_obj(category_code):
    try:
        return PostCategory.objects.get(code=category_code)
    except PostCategory.DoesNotExist:
        return ""


@register.simple_tag
def render_category(category_code):
    cate = get_object_or_404(PostCategory, code=category_code)
    posts = Post.objects.filter(active=True, cate=cate)

    return render_to_string('post/style/' + (cate.template or 'basic_list.html'), {
        'cate': cate,
        'posts': posts,
    })




# Generated by Django 2.1.7 on 2019-03-12 16:10

import ckeditor_uploader.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0010_auto_20190121_0157'),
    ]

    operations = [
        migrations.CreateModel(
            name='Popup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=300, verbose_name='제목')),
                ('is_active', models.BooleanField(default=False, verbose_name='활성화 여부')),
                ('pos_x', models.CharField(default='50px', max_length=100, verbose_name='팝업 가로 위치')),
                ('pos_y', models.CharField(default='100px', max_length=100, verbose_name='팝업 세로 위치')),
                ('content', ckeditor_uploader.fields.RichTextUploadingField(blank=True, help_text='팝업 내용을 직접 작성하는 경우 입력', null=True, verbose_name='팝업 내용')),
                ('image', models.ImageField(blank=True, help_text='설정시 팝업 내용은 이미지로 채워집니다.', null=True, upload_to='popup', verbose_name='이미지 팝업')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='생성일')),
                ('page', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='page.Page', verbose_name='표출 할 페이지')),
            ],
            options={
                'verbose_name': '팝업창',
                'verbose_name_plural': '팝업창 목록',
            },
        ),
    ]



# Generated by Django 2.1.4 on 2019-01-13 07:48

from django.db import migrations
import easy_thumbnails.fields


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0008_auto_20181209_2117'),
    ]

    operations = [
        migrations.AddField(
            model_name='post',
            name='featured',
            field=easy_thumbnails.fields.ThumbnailerImageField(blank=True, help_text='이미지 추가 시 페이지 상단에 이미지 타이틀이 표시 됩니다.', null=True, upload_to='featured', verbose_name='타이틀 이미지'),
        ),
    ]



# Generated by Django 2.0.5 on 2018-11-28 21:25

from django.db import migrations
import easy_thumbnails.fields


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0003_postcategory_link'),
    ]

    operations = [
        migrations.AlterField(
            model_name='page',
            name='featured',
            field=easy_thumbnails.fields.ThumbnailerImageField(blank=True, null=True, upload_to='featured', verbose_name='타이틀 이미지'),
        ),
    ]



# Generated by Django 2.0.5 on 2018-12-02 09:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0004_auto_20181129_0625'),
    ]

    operations = [
        migrations.AlterField(
            model_name='downloadablefile',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to='forms', verbose_name='양식 파일'),
        ),
    ]



# Generated by Django 2.0.5 on 2018-11-14 16:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0002_auto_20181114_0429'),
    ]

    operations = [
        migrations.AddField(
            model_name='postcategory',
            name='link',
            field=models.CharField(blank=True, max_length=1024, null=True, verbose_name='키테고리 페이지 링크'),
        ),
    ]



# Generated by Django 2.0.5 on 2018-11-11 11:02

import ckeditor_uploader.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DownloadableFile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=40, verbose_name='표시 할 파일명')),
                ('file', models.FileField(upload_to='forms', verbose_name='양식 파일')),
                ('created', models.DateField(auto_now_add=True, verbose_name='생성일자')),
            ],
            options={
                'verbose_name': '다운로드용 파일',
                'verbose_name_plural': '다운로드용 파일 목록',
            },
        ),
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=40, verbose_name='페이지 제목')),
                ('subtitle', models.CharField(blank=True, max_length=100, null=True, verbose_name='페이지 부제목(선택)')),
                ('featured', models.ImageField(blank=True, null=True, upload_to='featured', verbose_name='타이틀 이미지')),
                ('theme', models.CharField(blank=True, choices=[('', '밝게'), ('dark', '어둡게'), ('gray', '회색조'), ('custom', '커스텀')], default='', max_length=10, verbose_name='컬러 테마')),
                ('code', models.SlugField(unique=True, verbose_name='페이지 코드')),
                ('content', ckeditor_uploader.fields.RichTextUploadingField(verbose_name='페이지 내용')),
                ('style', models.TextField(blank=True, default='', null=True, verbose_name='Style')),
                ('script', models.TextField(blank=True, default='', null=True, verbose_name='Script')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='업데이트')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='생성일')),
            ],
            options={
                'verbose_name': '페이지',
                'verbose_name_plural': '페이지 목록',
            },
        ),
        migrations.CreateModel(
            name='Pagelet',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=40, verbose_name='문구 제목')),
                ('code', models.SlugField(unique=True, verbose_name='문구 코드')),
                ('content', ckeditor_uploader.fields.RichTextUploadingField(verbose_name='문구 내용')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='업데이트')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='생성일')),
            ],
            options={
                'verbose_name': '반복사용문구',
                'verbose_name_plural': '반복사용문구 목록',
            },
        ),
        migrations.CreateModel(
            name='Post',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('topmost', models.BooleanField(default=False, help_text='선택 시 리스트 상단에 고정 됩니다.', verbose_name='상단고정')),
                ('active', models.BooleanField(default=True, help_text='체크 되어 있을 때 리스트에 표시 됩니다', verbose_name='표시여부')),
                ('title', models.CharField(max_length=40, verbose_name='포스트 제목')),
                ('content', ckeditor_uploader.fields.RichTextUploadingField(verbose_name='포스트 내용')),
                ('summery', models.TextField(verbose_name='요약 내용')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='업데이트')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='생성일')),
            ],
            options={
                'verbose_name': '포스트',
                'verbose_name_plural': '포스트 목록',
                'ordering': ['-topmost', '-created'],
            },
        ),
        migrations.CreateModel(
            name='PostCategory',
            fields=[
                ('code', models.CharField(max_length=10, primary_key=True, serialize=False, verbose_name='카테고리 코드')),
                ('name', models.CharField(max_length=40, verbose_name='카테고리 제목')),
                ('desc', models.CharField(max_length=80, verbose_name='카테고리 한줄 설명')),
                ('template', models.CharField(blank=True, default=None, help_text='이 카테고리가 특수한 템플릿을 쓸 경우 템플릿명', max_length=80, null=True, verbose_name='특수 템플릿')),
            ],
            options={
                'verbose_name': '포스트 카테고리',
                'verbose_name_plural': '포스트 카테고리 목록',
            },
        ),
        migrations.AddField(
            model_name='post',
            name='cate',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='page.PostCategory'),
        ),
    ]



# Generated by Django 2.0.5 on 2018-12-08 12:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0006_auto_20181208_2018'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='slide',
            options={'ordering': ['order'], 'verbose_name': '슬라이드', 'verbose_name_plural': '슬라이드'},
        ),
        migrations.AlterField(
            model_name='slide',
            name='button_label',
            field=models.CharField(blank=True, help_text='공백인 경우 버튼이 표시 되지 않음', max_length=40, null=True, verbose_name='버튼 이름 제목'),
        ),
        migrations.AlterField(
            model_name='slide',
            name='delay',
            field=models.PositiveIntegerField(default=12, help_text='슬라이드가 표시되는 시간(초)', verbose_name='표시시간'),
        ),
    ]
